@@ -1,6 +1,7 @@
 package Rose::DBx::Object::Loader::FormMaker;
 
 use strict;
+use warnings;
 
 use Rose::DB::Object::Loader;
 use Carp;
@@ -8,23 +9,25 @@ use Cwd;
 use File::Path;
 use File::Spec;
 use Rose::Object::MakeMethods::Generic (
-    scalar => ['base_tabindex']
+  scalar => ['base_tabindex']
 );
-our $VERSION = '0.03_01';
-
 BEGIN { our @ISA = qw(Rose::DB::Object::Loader) }
 
 =head1 NAME
 
-Rose::DBx::Object::Loader::FormMaker - Automatically create RHTMLO Forms with the RDBO Loader
+Rose::DB::Object::Loader::FormMaker - Automatically create RHTMLO forms for RDBO Objects
 
-=head1 SYNOPSIS
+=head1 VERSION
 
-hi there
+version 0.01
+
+=cut
+
+our $VERSION = '0.01';
 
 =head2 B<make_modules [PARAMS]>
 
-see the documentation for Rose::DB::Object::Loader for the bulk of the
+see the documentation for Rose::DB::Object::Loader for the bulk of the 
 configuration options for make_modules. FormMaker adds a couple of options
 to what Loader provides described below:
 
@@ -54,22 +57,22 @@ sub make_modules {
 
     my @classes = $self->SUPER::make_modules(%args);
 
-    my $module_dir = exists $args{'module_dir'} ?
+    my $module_dir = exists $args{'module_dir'} ? 
         delete $args{'module_dir'} : $self->module_dir;
 
     $module_dir = cwd()  unless(defined $module_dir);
-
+    
     my @form_classes;
     foreach my $class (@classes) {
 
         next unless ($class->isa('Rose::DB::Object'));
 
         my $class_name = scalar $class;
-        my $class_prefix = $self->class_prefix;
-        my $form_prefix = $self->form_prefix;
+	my $class_prefix = $self->class_prefix;
+	my $form_prefix = $self->form_prefix;
 
-        $class_name =~ s|$class_prefix|$form_prefix|;
-        push @form_classes, $class_name;
+	$class_name =~ s|$class_prefix|$form_prefix|;
+	push @form_classes, $class_name;
 
         my @path = split('::', $class_name);
         $path[-1] .= '.pm';
@@ -91,15 +94,15 @@ sub make_modules {
 
         open(my $pm, '>', $file) or croak "Could not create $file - $!";
 
-        my $preamble = exists $args{'module_preamble'} ?
+        my $preamble = exists $args{'module_preamble'} ? 
             $args{'module_preamble'} : $self->module_preamble;
 
-        my $postamble = exists $args{'module_postamble'} ?
+        my $postamble = exists $args{'module_postamble'} ? 
             $args{'module_postamble'} : $self->module_postamble;
 
         if ($class->isa('Rose::DB::Object')) {
             if($preamble) {
-                my $this_preamble = ref $preamble eq 'CODE' ?
+                my $this_preamble = ref $preamble eq 'CODE' ? 
                     $preamble->($class->meta) : $preamble;
 
                 print {$pm} $this_preamble;
@@ -108,7 +111,7 @@ sub make_modules {
             print {$pm} $self->class_to_form($class);
 
             if($postamble) {
-                my $this_postamble = ref $postamble eq 'CODE' ?
+                my $this_postamble = ref $postamble eq 'CODE' ? 
                     $postamble->($class->meta) : $postamble;
 
                 print {$pm} $this_postamble;
@@ -117,14 +120,14 @@ sub make_modules {
     }
     push @classes, @form_classes;
 
-    return wantarray ? @classes : \@classes;
+    return wantarray ? @classes : \@classes; 
 }
 
 =head2 class_to_form
 
 =over 4
 
-class_to_form takes an RDBO class, and using it's meta information
+class_to_form takes an RDBO class, and using it's meta information 
 constructs an RHTMLO Form object.
 
 =back
@@ -137,7 +140,7 @@ sub class_to_form {
     my $class_prefix = $self->class_prefix;
     my $form_prefix = $self->form_prefix;
     $class_name =~ s|$class_prefix|$form_prefix|;
-
+    
     my $code;
 
     my $base_classes = $self->form_base_classes;
@@ -145,7 +148,7 @@ sub class_to_form {
     my $isa;
     foreach my $class (@$base_classes) {
         $uses .= $uses ? qq[\n] . qq[use $class;] : qq[use $class;];
-        $isa .= $isa ? qq[ ]. $class : $class;
+	$isa .= $isa ? qq[ ]. $class : $class;
     }
 
     $code .=qq[package $class_name;
@@ -165,22 +168,14 @@ sub build_form {
     foreach my $column (sort __by_rank $class->meta->columns){
         #print STDERR $column.qq[ ] . $column->type .qq[\n];
         #$code .= $column.qq[\n];
-        my $form_info = [
-            [ id => scalar $column ],
-            [ type => $column->type ],
-            [ label => scalar $column ],
-            [ tabindex => $count ],
-        ];
-        if ($column->length) {
-            push @$form_info, ['maxlength' => $column->length];
-        }
-
-        $code .= qq[\n        ] . scalar $column . qq[ => {];
-        foreach my $row (@$form_info) {
-            my ($key,$value) = @$row;
-            $code .= qq[\n            $key => '$value',];
-        }
-        $code .= qq[\n        },];
+	my $column_name = scalar $column;
+        $code .= qq[
+        $column_name => {
+            id => '$column_name',
+	    type => '].$column->type.qq[',
+            label => '$column_name',
+	    tabindex => $count,
+        },];
         $count++;
     }
     $code .= qq[
@@ -189,7 +184,7 @@ sub build_form {
 
 1;
 ];
-
+    
     return $code;
 }
 
@@ -219,7 +214,7 @@ sub form_prefix {
 #
 # ripped from loader to sort columns
 #
-sub __by_rank {
+sub __by_rank {  
   my $pos1 = $a->ordinal_position;
   my $pos2 = $b->ordinal_position;
 
@@ -242,21 +237,19 @@ sub form_base_classes {
     unless (@_) {
         if (my $bc = $self->{'form_base_classes'}) {
             return wantarray ? @$bc : $bc;
+	}
+	my $bc = [qq[Rose::HTML::Form]];
+	
+	return wantarray ? @$bc : $bc;
     }
-    my $bc = [qq[Rose::HTML::Form]];
-
-    return wantarray ? @$bc : $bc;
-    }
-
+    
     my $bc = shift;
 
     unless (ref($bc)) {
         $bc = [ $bc ];
     }
-
+    
     $self->{'form_base_classes'} = $bc;
     return wantarray ? @$bc : $bc;
 
 }
-
-1;
